# PyArchetype

This project is used to simplify the skeleton creation of python projects

## Installation

pip install pyarchetype

## Syntax

Tool to create the skeleton of a python project

optional arguments:
  -h, --help         show this help message and exit
  -v, --version      show program's version number and exit
  --path PATH        basedir. Default current dir
  --module MODULE    Module name . Default value is app
  --force_overwrite  Force overwrite. Default value is false
  --create_venv      Create project virtualenv. Default value is false

Version: 2023010600